@@ -75,3 +75,15 @@ class QuandlCommoditiesData:
         return result    
     
 
+    def existing_index(self):
+        '''  
+        Returns
+        -------
+        ``List``
+            existing index values that can pe pushed to `load`
+        '''
+        index = [x.split('.json')[0] for x in os.listdir(self.data_path)]
+        return index 
+
+
+
